@@ -1,12 +1,7 @@
 from django.contrib.gis.db import models
 from django.utils.text import slugify
 
-
-__all__ = [
-    'Location',
-    'LocatedFile',
-    'BoxedLocation'
-]
+__all__ = ['Location', 'LocatedFile', 'BoxedLocation', 'Nullable']
 
 
 class BaseModel(models.Model):
@@ -18,13 +13,13 @@ class BaseModel(models.Model):
     class Meta:
         abstract = True
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def _generate_slug(self):
         if self.slug == '' or self.slug is None:
             try:
-                name = unicode(self.name)
+                name = str(self.name)
             except NameError:
                 name = self.name
             self.slug = slugify(name)
@@ -34,7 +29,7 @@ class BaseModel(models.Model):
 
     def save(self, *args, **kwargs):
         self._generate_slug()
-        super(BaseModel, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
 
 class Location(BaseModel):
@@ -47,3 +42,7 @@ class LocatedFile(BaseModel):
 
 class BoxedLocation(BaseModel):
     bbox_geometry = models.PolygonField()
+
+
+class Nullable(BaseModel):
+    geometry = models.GeometryField(blank=True, null=True)
